<?php

/**
 * @file
 */

/**
 * Load the a class file.
 *
 * @param $name
 *   Type: string; The name of the class to load.
 */
function cafepress_load_class($name) {
  static $set = FALSE;

  if (!$set) {
    module_load_include('class', 'cafepress', 'classes/cafepress.cafepress');
    cafepress::getInstance()->apiKey = variable_get('cafepress_apikey', '');
    cafepress::getInstance()->handlers['setCache'] = 'cafepress_cache_set';
    cafepress::getInstance()->handlers['getCache'] = 'cafepress_cache_get';
    $set = TRUE;
  }

  cafepress::getInstance()->loadClass($name);
}

/**
 * Cache API response data.
 *
 * @param $data
 *   Type: string; The XML response data to cache.
 * @param $params
 *   Type: array; Associative array with key-value pairs.
 * @param $class
 *   Type: string; The class the method is from.
 * @param $method
 *   Type: string; The method that has called the API.
 */
function cafepress_cache_set($data, $params, $class, $method) {
  $expire = time() + 604800;
  cache_set(cafepress::getInstance()->implodeParams($params), $data, 'cache_cafepress', $expire);
}

/**
 * Fetch API response data from the cache.
 *
 * @param $params
 *   Type: array; Associative array with key-value pairs.
 * @param $class
 *   Type: string; The class the method is from.
 * @param $method
 *   Type: string; The method that has called the API.
 */
function cafepress_cache_get($params, $class, $method) {
  $data = cache_get(cafepress::getInstance()->implodeParams($params), 'cache_cafepress');

  return $data->data;
}

/** 
 * Helper function to get an array of the products to display 
 **/
function cafepress_get_products($store, $image_size) {
  
      $imageDir = variable_get("cafepress_image_dir", "images/cafepress");

      cafepress_load_class('product');

      $products = new cafepressproduct($store);

      $cafetagdata = $products->listByStore(urlencode($store));

      $product_list = array();

      foreach ($cafetagdata->product as $prods ) {

//      We'll need this for later to pick the right picture.
        $perspective = $prods['defaultPerspective'];

//      Check the number of colors listed, so we can list if others
//      are available.

//      Loop to find the default color id number so we can select the
//      right picture.
        if ( count($prods->color)!== 0 ) {
          foreach ($prods->color as $colors ) {
            if ( $colors['default'] == "true" ) {
              $color_id = $colors['id'];
            }
          }
        }
        else {
          $color_id = '0';
        }

//  We have what we need now find the right image

        foreach ($prods->productImage as $image_data ) {
          if ( strcmp($image_data['colorId'], $color_id) == 0 &&
               $image_data['imageSize'] == $image_size  &&
               strcmp($image_data['perspectiveName'],$perspective ) == 0 ) {
            $product_url = $image_data['productUrl'] ;
          }
        }

     $filename = end(explode('/',$product_url));

     $image_path = file_directory_path() . '/' . $imageDir ;
     file_check_directory($image_path, FILE_CREATE_DIRECTORY) ;
     $local_file = file_scan_directory($image_path, $filename);

     if ( empty($local_file) ) {

// The file is not here, pull it from CP and save it.
      $image_data = @file_get_contents($product_url);
      file_save_data($image_data, $image_path . '/' . $filename); 
     }  

     $file_index = $image_path . '/' . $filename;

      $product_list[] = array('id'=>(string) $prods['id'], 'name'=>(string) $prods['name'], 'url'=>file_create_url($file_index), 'count'=>count($prods->color), 'caption'=>(string) $prods['defaultCaption'], 'price'=>(string) $prods['sellPrice']);
      }

      return $product_list;
}